@@ -168,6 +168,7 @@ class Document (Connector.Publisher):
             ('Paste', gtk.STOCK_PASTE,  None,         None,   None,     self.paste_entry),
             ('Clear', gtk.STOCK_CLEAR,  None,         None,   None,     self.clear_entries),
             ('Add', gtk.STOCK_ADD,  None,   '<shift><control>n',  _('Add a new entry'), self.add_entry),
+            ('Edit', gtk.STOCK_EDIT,  None, '<shift><control>o',   None,     self.edit_entry),
             ('Delete', gtk.STOCK_DELETE,  None,         None,   None,     self.delete_entry),
             ('Find', gtk.STOCK_FIND,  None,         None,   None,     self.find_entries),
             
@@ -180,21 +181,11 @@ class Document (Connector.Publisher):
             ('Forget', None, _('Forget all changes'),     None,   None,     self.forget_changes_cb),
             
             ('Contents', gtk.STOCK_HELP, None,   None,   None,     self.on_documentation),
+            ('About', gtk.STOCK_ABOUT, None,   None,   None,     self.about),
 	    ('ViewResource', None, _('_Resource'), None, None, self.view_entry),
             ])
 
-        if gtk.pygtk_version >= (2,6,0):
-            self.actiongroup.add_actions ([
-                ('About', gtk.STOCK_ABOUT, None,   None,   None,     self.about),
-                ('Edit', gtk.STOCK_EDIT,  None, '<shift><control>o',   None,     self.edit_entry),
-                ])
 
-        else:
-            self.actiongroup.add_actions ([
-                ('About', None, _('_About'),   None,   None,     self.about),
-                ('Edit', None,  _('_Edit'),    '<shift><control>o', None,    self.edit_entry),
-                ])
-            
         prev = self.actiongroup.get_action ('Recent')
         
         prev.set_property ('is-important', True)
@@ -475,9 +466,13 @@ class Document (Connector.Publisher):
 				       self.w).answer ()
       
 	    else:
-		if Utils.Callback (_("The database has been modified.\nSave changes?"),
-				   self.w).answer () and self.modification_check ():
-		    self.save_document ()
+		answer = Utils.Callback (_("The database has been modified.\nSave changes?"),
+				         self.w, cancel_add = True).answer ()
+                if answer == 2:
+                    return False
+                elif answer and self.modification_check ():
+                    self.save_document ()
+                    return True
 		else:
 		    return True
 	return 1
@@ -492,7 +487,7 @@ class Document (Connector.Publisher):
             
             if mod_date > self.modification_date:
                 return  Utils.Callback (
-		    _("The database has been externally modified.\nOverwrite changes ?"),
+		    _("The database has been externally modified.\nOverwrite changes?"),
 		    self.w).answer ()
 	    
 	return True
@@ -525,7 +520,7 @@ class Document (Connector.Publisher):
             return
         elif url is -1:
             # error
-            self.w.error (_("An error occured during Medline Query"))
+            self.w.error (_("An error occurred during Medline Query"))
             return
 
         self.open_in_new(url, 'medline', no_name=True)
@@ -710,7 +705,7 @@ class Document (Connector.Publisher):
                 self.w.error (_("Error during autosaving:\n%s") % error [1])
                 return False
 
-            iterator = Selection.Selection (sort = self.selection.sort)
+            iterator = Selection.Selection (sort = Sort.Sort([Sort.KeySort()]))
             Open.bibwrite (iterator.iterator (self.data.iterator ()),
                            out = savefile, how = how, database=self.data)
 
@@ -732,7 +727,7 @@ class Document (Connector.Publisher):
         Utils.set_cursor (self.w, 'clock')
         try:
             try:
-                self.data.update (self.selection.sort)
+                self.data.update (Sort.Sort([Sort.KeySort()]))
             except (OSError, IOError), error:
                 Utils.set_cursor (self.w, 'normal')
                 self.w.error (_("Unable to save `%s':\n%s") % (str (self.data.key),
@@ -743,7 +738,7 @@ class Document (Connector.Publisher):
             traceback.print_exception (etype, value, tb)
             
             Utils.set_cursor (self.w, 'normal')
-            self.w.error (_("An internal error occured during saving\nTry to Save As..."))
+            self.w.error (_("An internal error occurred during saving\nTry to Save As..."))
             return
 
         Utils.set_cursor (self.w, 'normal')
@@ -764,7 +759,7 @@ class Document (Connector.Publisher):
 
         if os.path.exists (url):
             if not Utils.Callback (
-		_("The file `%s' already exists.\nOverwrite it ?")
+		_("The file `%s' already exists.\nOverwrite it?")
 		% url, parent = self.w).answer ():
                 return
 
@@ -776,7 +771,7 @@ class Document (Connector.Publisher):
 
         Utils.set_cursor (self.w, 'clock')
 
-        iterator = Selection.Selection (sort = self.selection.sort)
+        iterator = Selection.Selection (sort = Sort.Sort([Sort.KeySort()]))
         Open.bibwrite (iterator.iterator (self.data.iterator ()),
                        out = file, how = how, database=self.data)
         file.close ()
@@ -882,7 +877,7 @@ class Document (Connector.Publisher):
         for entry in entries:
             
             if self.data.would_have_key (entry.key):
-                if not Utils.Callback (_("An entry called `%s' already exists.\nRename and add it anyway ?")
+                if not Utils.Callback (_("An entry called `%s' already exists.\nRename and add it anyway?")
                                        % entry.key.key, parent = self.w).answer ():
                     continue
                 
@@ -919,7 +914,7 @@ class Document (Connector.Publisher):
     def clear_entries (self, * arg):
         if len (self.data) == 0: return
 
-        if not Utils.Callback (_("Really remove all the entries ?"),
+        if not Utils.Callback (_("Really remove all the entries?"),
                                parent = self.w).answer ():
             return
 
@@ -951,9 +946,10 @@ class Document (Connector.Publisher):
         l = len (entries)
 
         if l == 0: return
-        
+
         if l > 5:
-            if not Utils.Callback (_("Really edit %d entries ?") % l):
+            if not Utils.Callback (_("Really edit %d entries?")
+                                   % l, parent = self.w).answer ():
                 return
 
         for entry in entries:
@@ -999,9 +995,9 @@ class Document (Connector.Publisher):
         offset = self.index.get_item_position (entries [-1])
 
         if l > 1:
-            question = _("Remove all the %d entries ?") % len (entries)
+            question = _("Remove all the %d entries?") % len (entries)
         else:
-            question = _("Remove entry `%s' ?") % entries [0].key.key
+            question = _("Remove entry `%s'?") % entries [0].key.key
             
         if not Utils.Callback (question,
                                parent = self.w).answer ():
@@ -1187,7 +1183,7 @@ class Document (Connector.Publisher):
                 
                 self.incremental_start  = event.time
 
-            # search first occurence
+            # search first occurrence
             if self.index.go_to_first (self.incremental_search,
                                        self.selection.sort.fields [0]):
                 app.flash ("Searching for '%s...'" % self.incremental_search)
@@ -1220,7 +1216,7 @@ class Document (Connector.Publisher):
 
         timestamp = gtk.gdk.CURRENT_TIME
         try:
-            gtk.show_uri (None, "ghelp:pybliographer", timestamp)
+            gtk.show_uri (None, "help:pybliographer", timestamp)
             
         except gobject.GError, msg:
             self.w.error (_("Can't display documentation:\n%s") % msg)
@@ -1228,7 +1224,9 @@ class Document (Connector.Publisher):
         return
     
     def about (self, *arg):
-        
+
+	pybliologo = gtk.gdk.pixbuf_new_from_file(
+			os.path.join (version.pybdir, 'pixmaps', 'pybliographic-logo.png'))
         about = ui.About ('Pybliographic',
                           version.version,
                           _("This program is copyrighted under the GNU GPL"),
@@ -1243,7 +1241,8 @@ class Document (Connector.Publisher):
                           ['Yuri Bongiorno',
                            'Frédéric Gobry',
                            'Zoltán Kóta'],
-                          _('GNOME Translation Team'))
+                          _('GNOME Translation Team'),
+                          pybliologo)
 
         about.set_transient_for (self.w)
         
